## m2c

**workflow**

0. pip install m2c
1. mkdir **your-project-name**
2. cd **your-project-name**
3. m2c init
4. m2c build
5. m2c run
6. m2c debug
7. m2c unittest
8. m2c pack

**coding**

0. desgin apimodel.txt
1. m2c apicode
2. desgin objmodel.txt
3. m2c objcode
4. coding logic with api/obj...
5. coding unittest...
6. m2c unittest
7. m2c pack
8. done
